Green Unicorn - Community

## Mailing list

The user mailing list is general discussion and support list for Gunicorn users.

> - To subscribe, send an email to user+subscribe@gunicorn.org
> - To unsubscribe, send an email to user+unsubscribe@gunicorn.org
> - Finally, to post a message to the list use the address to user@gunicorn.org

The archive for this list can also be browsed online .

## Irc

The Gunicorn channel is on the Freenode IRC network. You can chat with other on #gunicorn channel.

## Issue Tracking

Bug reports, enhancement requests and tasks generally go in the Github issue tracker.